## Installation	

⚠️ ART 4.1 is the last version to support Python 2.7

### Source code
- Download [Version 4.1](https://github.com/sepandhaghighi/art/archive/v4.1.zip) or [Latest Source ](https://github.com/sepandhaghighi/art/archive/dev.zip)
- `python3 setup.py install` or `python setup.py install` (Need root access)				

### PyPI


- Check [Python Packaging User Guide](https://packaging.python.org/installing/)     
- `pip install art==4.1` or `pip3 install art==4.1` (Need root access)

* Note :  On `--upgrade` error install latest version of `setuptools` : `pip install setuptools` and retry

### Conda

- Check [Conda Managing Package](https://conda.io/docs/user-guide/tasks/manage-pkgs.html#installing-packages-from-anaconda-org)
- `conda install -c sepandhaghighi art ` (Need root access)

### Easy install

- Run `easy_install "art==4.1"` (Need root access)
